Skip to contents

This mass-specific consumption rate is used in detritus_dynamics() to calculate the detritus biomass at the next time step. To get the non-mass-specific consumption rate, use getDetritusConsumption().

Usage

detritus_consumption(params, n = params@initial_n, rates = getRates(params))

Arguments

params

MizerParams

n

A matrix of current species abundances (species x size)

rates

A list of rates as returned by getRates()

Value

The mass-specific consumption rate of detritus in grams per year.

Details

The rho parameter for each functional group is stored in other_params(params)$detritus$rho

Detritus consumption

The rate at which detritivorous consumer groups encounter detrital biomass \(E_{i.D}(w)\) is controlled by the parameter \(\rho_{D.i}\). It scales with the size of the consumer raised to an allometric exponent \(m_{det}\) which is taken to be the same as the scaling exponent of the maximum intake rate for fish consumers.

$$E_{i.D}(w)=\rho_{i.D}\, w^{m_{det}}\,B_D $$

The mass specific consumption rate then accounts for the preference of functional group $i$ for detritus, \(\theta_{i.D}\) and the feeding level \(f_i(w)\). This gives the mass-specific detritus consumption rate:

$$c_D = \sum_i\int\rho_{i.D}\, w^{m_{det}} N_i(w) \left(1-f_i(w)\right) \theta_{i.D}\,dw$$