Skip to contents

Calculates the detritus biomass at the next time step from the current detritus biomass

Usage

detritus_dynamics_cc(params, n, n_other, rates, dt, ...)

Arguments

params

A MizerParams object

n

A matrix of current species abundances (species x size)

n_other

Other dynamic components.

rates

A list of rates as returned by getRates()

dt

Time step size

...

Unused

Value

A single number giving the detritus biomass at next time step

Details

The time evolution of the detritus biomass \(B\) is described by

$$ \frac{dB_D}{dt} = P_D\left( 1 - \frac{B_D}{K_D} \right) - c_D \, B_D $$

where \(K_D\) is the system's carrying capacity for detritus in grams/ year, \(c_D\) is the mass-specific rate of consumption calculated with detritus_consumption() and \(P_D\) is the rate at which detritus is produced calculated with getDetritusProduction().

The dynamical equation is solved analytically to

$$B_D(t + dt) = B_D(t) \cdot e^{-\frac{dt}{K_D}(P_D+ K_D \, c_D)} + \frac{K_D \, P_D}{P_D+ K_D \, c_D} \left(1- e^{-\frac{dt}{K_D}(P_D+ K_D \, c_D)}\right) $$