Skip to contents

This function returns a named vector with one component for each species giving the rate in grams/year at which that species consumes detritus

Usage

getDetritusConsumption(params)

Arguments

params

MizerParams

Value

A named vector with the consumption rates from herbivores

Detritus consumption

The rate at which detritivorous consumer groups encounter detrital biomass \(E_{i.D}(w)\) is controlled by the parameter \(\rho_{D.i}\). It scales with the size of the consumer raised to an allometric exponent \(m_{det}\) which is taken to be the same as the scaling exponent of the maximum intake rate for fish consumers.

$$E_{i.D}(w)=\rho_{i.D}\, w^{m_{det}}\,B_D $$

The mass specific consumption rate then accounts for the preference of functional group $i$ for detritus, \(\theta_{i.D}\) and the feeding level \(f_i(w)\). This gives the mass-specific detritus consumption rate:

$$c_D = \sum_i\int\rho_{i.D}\, w^{m_{det}} N_i(w) \left(1-f_i(w)\right) \theta_{i.D}\,dw$$

See also

getAlgaeProduction(), algae_dynamics(), getDetritusConsumption()