Skip to contents

The group abundances, biomasses, productivities are calculated by the plotTotalAbundance(), plotTotalBiomass(), and plotProductivity() functions. These are passed all additional arguments you supply. See plotTotalAbundance(), plotTotalBiomass() and plotProductivity() for more details.

Usage

plotRelativeContribution(
  object,
  min_size = NULL,
  min_fishing_l = NULL,
  return_data = FALSE,
  ...
)

Arguments

object

An object of class MizerParams

min_size

parameters be passed to plotTotalAbundance() and plotTotalBiomass(). The minimum length (cm) of individuals for biomass estimates. Defaults to smallest size in the model.

min_fishing_l

parameters be passed to getProductivity(). The minimum length (cm) of fished individuals for productivity estimates. Defaults to 7 cm.

return_data

A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default value is FALSE.

...

Arguments passed on to plotTotalBiomass, plotTotalAbundance, plotProductivity

species

The species to be selected. Optional. By default all species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not.

max_fishing_l

The maximum length (cm) of for biomass estimates. Defaults to max length.

stack

A boolean value that determines whether bars are separated by species. Defaults to FALSE. If true, returns a stacked barplot with the total biomass for each group instead of individual bars for each group. Useful for comparison between steady states.

start_time

The first time to be plotted. Default is the beginning of the time series.

end_time

The last time to be plotted. Default is the end of the time series.

facet

A boolean value indicating whether to facet the result plot by species group. Defaults to TRUE.

total

A boolean value that determines whether the total productivity from all species is plotted as well. Default is TRUE.