Plot the total biomass for each species in a size range
Source:R/reef-analysis_plots.R
plotTotalBiomass.RdThis functions creates a barplot with the biomass of each specie
within a size range. Usually used in conjunction with plotProductivity()
to check for decoupling.
Usage
plotTotalBiomass(
object,
species = NULL,
min_fishing_l = NULL,
max_fishing_l = NULL,
return_data = FALSE,
...
)
plotlyTotalBiomass(object, ...)Arguments
- object
An object of class MizerParams or MizerSim. If a MizerSim object is provided, the biomass at the last time step is used.
- species
The species to be selected. Optional. By default all species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not.
- min_fishing_l
The minimum length (cm) for biomass estimates. Defaults to smallest size.
- max_fishing_l
The maximum length (cm) of for biomass estimates. Defaults to max length.
- return_data
A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default value is FALSE.
- ...
unused
See also
plotBiomass(), plot2TotalBiomass(),
plotTotalBiomassRelative(),
plotProductivity(), plot2Productivity(),
plotProductivityRelative()
Other plotting functions:
plot2Productivity(),
plot2TotalBiomass(),
plotDegScale(),
plotDegradationScale(),
plotProductivity(),
plotProductivityRelative(),
plotRefugeDensity(),
plotRefugeProfile(),
plotRelativeContribution(),
plotSpectraChange(),
plotTotalAbundance(),
plotTotalBiomassRelative(),
plotVulnerable()