Skip to contents

Calculates the total predation mortality rate \(\mu_{p,i}(w_p)\) (in units of 1/year) on each prey species by prey size:

Usage

reefPredMort(
  params,
  n,
  n_pp,
  n_other,
  t,
  pred_rate,
  vulnerable = reefVulnerable(params, n, n_pp, n_other, t, new_rd = reefDegrade(params,
    n, n_pp, n_other, t)),
  ...
)

Arguments

params

A MizerParams object

n

A matrix of species abundances (species x size).

n_pp

A vector of the resource abundance by size

n_other

A list of abundances for other dynamical components of the ecosystem

t

The time for which to do the calculation (Not used by standard mizer rate functions but useful for extensions with time-dependent parameters.)

pred_rate

A two dimensional array (predator species x predator size) with the predation rate

vulnerable

Array (species x size) with the proportion of individuals that are not protected from predation by refuge

...

Unused

Value

A two dimensional array (prey species x prey size) with the predation mortality

Details

$$\mu_{p.i}(w_p) = \sum_j {\tt pred\_rate}_j(w_p)\, V_{ji}(w_p)\, \theta_{ji}.$$

You would not usually call this function directly but instead use getPredMort(), which then calls this function.