This multiplies the algae biomass by a factor and divides the interaction between all species and algae by the same factor, so as to keep the total consumption of algae unchanged.
This multiplies the algae biomass by a factor and divides the interaction between all species and algae by the same factor, so as to keep the total consumption of algae unchanged.