Rescale detritus biomass without changing anything else
Source:R/detritus_components.R
rescale_detritus.RdThis multiplies the detritus biomass by a factor and divides the interaction between all species and the detritus by the same factor, so as to keep the total consumption of detritus unchanged.