Skip to contents

This is the rate in grams/year/m^-2 at which the system produces algae biomass. The rate is set so that production and consumption are equal for chosen steady state abundances.

Usage

getAlgaeProduction(params)

Arguments

params

MizerParams

Value

The annual growth rate of algae per square meter

See also