Plots the refuge density at each size bin through time as colored lines, showing how refuge degrades over the course of a simulation. Uses viridis color scale to represent temporal succession.
Arguments
- sim
A MizerSim object
- return_data
A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default value is FALSE.
- ...
Unused
Value
A ggplot2 object, unless return_data = TRUE, in which case a data
frame with refuge density at each size and time
See also
plotting_functions, setRefuge(), reefDegrade()
Other plotting functions:
plot2Productivity(),
plot2TotalBiomass(),
plotDegScale(),
plotDegradationScale(),
plotProductivity(),
plotProductivityRelative(),
plotRefugeProfile(),
plotRelativeContribution(),
plotSpectraChange(),
plotTotalAbundance(),
plotTotalBiomass(),
plotTotalBiomassRelative(),
plotVulnerable()