Plot the relative contribution of each species group to total abundance, total biomass, and total productivity
plotRelativeContribution.RdThe group abundances, biomasses, productivities are calculated by the
plotTotalAbundance(), plotTotalBiomass(), and plotProductivity()
functions. These are passed all additional arguments you supply. See
plotTotalAbundance(), plotTotalBiomass() and plotProductivity()
for more details.
Usage
plotRelativeContribution(
object,
min_size = NULL,
min_fishing_l = NULL,
return_data = FALSE,
...
)Arguments
- object
An object of class MizerParams
- min_size
parameters be passed to
plotTotalAbundance()andplotTotalBiomass(). The minimum length (cm) of individuals for biomass estimates. Defaults to smallest size in the model.- min_fishing_l
parameters be passed to
getProductivity(). The minimum length (cm) of fished individuals for productivity estimates. Defaults to 7 cm.- return_data
A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default value is FALSE.
- ...
Arguments passed on to
plotTotalBiomass,plotTotalAbundance,plotProductivityspeciesThe species to be selected. Optional. By default all species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not.
max_fishing_lThe maximum length (cm) of for biomass estimates. Defaults to max length.
stackA boolean value that determines whether bars are separated by species. Defaults to FALSE. If true, returns a stacked barplot with the total biomass for each group instead of individual bars for each group. Useful for comparison between steady states.
start_timeThe first time to be plotted. Default is the beginning of the time series.
end_timeThe last time to be plotted. Default is the end of the time series.
facetA boolean value indicating whether to facet the result plot by species group. Defaults to TRUE.
totalA boolean value that determines whether the total productivity from all species is plotted as well. Default is TRUE.
See also
plotTotalAbundance(), plotTotalBiomass(), plotProductivity()
Other plotting functions:
plot2Productivity(),
plot2TotalBiomass(),
plotBiomass(),
plotProductivity(),
plotProductivityRelative(),
plotRefuge(),
plotSpectraRelative(),
plotTotalAbundance(),
plotTotalBiomass(),
plotTotalBiomassRelative(),
plotVulnerable()