Plot the vulnerability to predation of species by weight
Source:R/reef-parameter_plots.R
plotVulnerable.RdPlot the vulnerability to predation of species by weight
Usage
plotVulnerable(
object,
species = NULL,
all.sizes = FALSE,
time_step = NULL,
return_data = FALSE,
...
)
plotlyVulnerable(
object,
species = NULL,
all.sizes = FALSE,
return_data = FALSE,
...
)Arguments
- object
An object of class MizerParams or MizerSim. If a MizerSim object is provided, the abundance at the last time step is used.
- species
The species to be selected. Optional. By default all species are selected. A vector of species names, or a numeric vector with the species indices, or a logical vector indicating for each species whether it is to be selected (TRUE) or not.
- all.sizes
If TRUE, then vulnerability is plotted also for sizes outside a species' size range. Default FALSE.
- time_step
If
objectis a MizerSim object, this optional parameter specifies which time step to use for calculating vulnerability. Default is the last time step.- return_data
A boolean value that determines whether the formatted data used for the plot is returned instead of the plot itself. Default value is FALSE.
- ...
unused
Value
A ggplot2 object, unless return_data = TRUE, in which case a data
frame the vulnerability at each size
Details
When called with a MizerParams object the initial vulnerability is plotted. The complement of refuge.
See also
plotting_functions, setRefuge(), plotRefugeProfile()
Other plotting functions:
plot2Productivity(),
plot2TotalBiomass(),
plotDegScale(),
plotDegradationScale(),
plotProductivity(),
plotProductivityRelative(),
plotRefugeDensity(),
plotRefugeProfile(),
plotRelativeContribution(),
plotSpectraChange(),
plotTotalAbundance(),
plotTotalBiomass(),
plotTotalBiomassRelative()