Interactive Plotly version of plotDegradationScale
Source:R/reef-parameter_plots.R
plotlyDegradationScale.RdReturns an interactive heatmap for degradation scaling parameters.
Arguments
- object
An optional object of class MizerParams or MizerSim. If provided, the function will attempt to extract the degradation scaling or trajectory from its
@other_params$refuge_paramsslot.- trajectory
Optional. Either a character string (
"rubble","algae","recovery") to use built-in data, or a user-provided numeric matrix/data.frame with refuge size bins as rows and bleaching years as columns (column 1 = bleaching year, remaining columns = years 1, 2, 3... post-bleaching).- return_data
Logical. If TRUE, returns the formatted data frame instead of the plot. Default FALSE.
- ...
Extra parameters passed on to
plotly::ggplotly().