Scales the refuge density by a given value at set times
Source:R/reef-project_methods.R
reefDegrade.RdAllows for the gradual degradation of habitat structure following an acute disturbance by decreasing the availability of refuge over time.
Arguments
- params
A MizerParams object
- n
A matrix of species abundances (species x size).
- n_pp
A vector of the resource abundance by size
- n_other
A list of abundances for other dynamical components of the ecosystem
- t
The time for which to do the calculation (Not used by standard mizer rate functions but useful for extensions with time-dependent parameters.)
- ...
Unused
Details
The degradation is controlled by a scaling matrix deg_scale where:
Column 1 represents the bleaching year (initial impact)
Columns 2+ represent years 1, 2, 3... post-bleaching
At each timestep, the scaling factors are multiplied by the previous
timestep's refuge density. setDegradation() can also configure an
independent, optional post-bleaching algae growth/capacity boost (see
getAlgaeBoost()); that boost is unrelated to refuge density and is not
computed by this function.
See also
Other mizer rate functions:
reefEncounter(),
reefFeedingLevel(),
reefMort(),
reefPredMort(),
reefRates(),
reefVulnerable()