Scales the refuge density by a given value at set times
reefDegrade.RdAllows for the degradation of coral reef habitat structure following an acute disturbance by decreasing the availability of refuge over time.
Arguments
- params
A MizerParams object
- n
A matrix of species abundances (species x size).
- n_pp
A vector of the resource abundance by size
- n_other
A list of abundances for other dynamical components of the ecosystem
- t
The time for which to do the calculation (Not used by standard mizer rate functions but useful for extensions with time-dependent parameters.)
- ...
Unused
See also
Other mizer rate functions:
reefEncounter(),
reefFeedingLevel(),
reefMort(),
reefPredMort(),
reefRates(),
reefVulnerable()