Reef feeding level
reefFeedingLevel.RdThis function replaces the usual mizerFeedingLevel() function and returns
the a feeding level of 0 for piscivores.
Arguments
- params
A MizerParams object
- n
A matrix of species abundances (species x size).
- n_pp
A vector of the resource abundance by size
- n_other
A list of abundances for other dynamical components of the ecosystem
- t
The time for which to do the calculation (Not used by standard mizer rate functions but useful for extensions with time-dependent parameters.)
- encounter
A two dimensional array (predator species x predator size) with the encounter rate.
- ...
Unused
See also
Other mizer rate functions:
reefDegrade(),
reefEncounter(),
reefMort(),
reefPredMort(),
reefRates(),
reefVulnerable()