Rescale detritus biomass without changing anything else
rescale_detritus.RdThis multiplies the detritus biomass by a factor and divides the interaction between all species and the detritus by the same factor, so as to keep the total consumption of detritus unchanged. It also divides the mass-specific rate of decomposition by the same factor so that the total detritus decomposition rate stays the same.