Prepare a steady state model for projections with degradation
Source:R/reef-setParams.R
setDegradation.RdThis function stores degradation parameters in the refuge_params slot of
the params object, and algae adjustment parameters in other_params$algae.
Arguments
- params
a mizer object
- trajectory
Optional character string naming the degradation scenario. Used for documentation and identification. No functional effect on the simulation.
- deg_scale
A matrix (refuge bins x time) giving scaling factors for refuge density. Column 1 represents the bleaching year (initial impact), and subsequent columns represent years 1, 2, 3... post-bleaching. Values are multiplied by the previous timestep's refuge density. Default scaling matrices for 15 years with "rubble", "algae", and "recovery" trajectories are included as data objects in the package.
- bleach_time
The year of the simulation to implement bleaching. Defaults to year 2.
- degrade
Logical. Whether to enable habitat degradation during projections, i.e. whether
reefDegrade()applies thedeg_scaletrajectory oncetreachesbleach_time. Default FALSE.- algae_boost
Logical. Should algae growth and/or carrying capacity be adjusted in response to bleaching? Default is FALSE.
- algae_growth_boost
Numeric vector. Multipliers for algae growth rate at bleaching (element 1) and during post-bleaching years (subsequent elements). Only used if algae_boost = TRUE. Vector length determines duration: length 4 means bleaching year plus 3 post-bleaching years. Default is c(1.11, 1.11, 1.11, 1.11) for 4 years of boosting.
- algae_capacity_boost
Numeric vector. Multipliers for algae carrying capacity at bleaching (element 1) and during post-bleaching years (subsequent elements). Only used if algae_boost = TRUE. If shorter than algae_growth_boost, will be padded with 1s (no change). Default is c(2.0) (only boosts at bleaching year).
- ...
Unused