Switch to unstructured resource dynamics with carrying capacities
setURcapacity.RdThis function calculates new carrying capacities for algae and detritus resources and switches the resource dynamics from the standard linear dynamics to fluxes with a carrying capacity. The carrying capacity is set at two times the current steady state biomass of the resource.
Details
See algae_dynamics_cc() and detritus_dynamics_cc() for additional detail.
See also
algae_dynamics_cc(),detritus_dynamics_cc(),
tune_UR_cc()