Skip to contents

This first sets the rate of degradation of algae so that for the given abundances, the algae is at steady state. It then sets the rate at which detritus flows in from external sources (e.g. the pelagic zone) so that for the given abundances the detritus is at steady state.

Usage

tuneUR(params, ...)

Arguments

params

A MizerParams object

...

unused

Value

An updated MizerParams object