Tune unstructured resources (algae and detritus) to steady state
tuneUR.RdThis first sets the rate of degradation of algae so that for the given abundances, the algae is at steady state. It then sets the rate at which detritus flows in from external sources (e.g. the pelagic zone) so that for the given abundances the detritus is at steady state.