Skip to contents

This is a 2-dimensional array containing start and end lengths for size bins and prop_protect equal to 20% for all size bins up to 50 cm in length.

Usage

tuning_profile

Format

dataframe

PhD Thesis

Details

These refuge parameters are intended for tuning the steady state when using the density-dependent competitive method. The tuning profile provides a constant proportion of refuges to all fish up to 50 cm in length.

When creating a model using the competitive method, you should run newReefParams() with the "binned" method and a proportional tuning profile.

After species biomasses and growth rates have been calibrated to match empirical observations, use the newRefuge() function to implement your competitive refuge parameters. After using newRefuge(), make sure to iterate through mizer:: matchBiomasses(), matchReefGrowth(), and reefSteady() again to regain the steady state.